@@ -55,13 +55,9 @@ struct _GlobalConfig {
 	GlobalConfigKey    screenshot_key;
 	GlobalConfigKey    window_screenshot_key;
 
-	gboolean           autoraise;
 	gboolean           drawer_auto_close;
 	gboolean           confirm_panel_remove;
 	gboolean           highlight_when_over;
-
-	int                menu_flags;
-	gboolean           menu_check;
 };
 
 void panel_global_config_set_entry (GConfEntry  *entry);
